import { Socket } from '@codeloop/socketio';
/**
 * A demo controller for socket.io
 *
 * ```ts
 * @socketio('/')
 * ```
 * This specifies the namespace / for this controller
 * Regex or strings are acceptable values for namespace
 */
export declare class SocketIoController {
    private socket;
    constructor(socket: Socket);
    /**
     * The method is invoked when a client connects to the server
     *
     * @param socket - The socket object for client
     */
    connect(socket: Socket): Promise<void>;
    /**
     * Register a handler for 'subscribe-to-channel' events
     *
     * @param msg - The message sent by client
     */
    registerChannel(msg: string[]): Promise<void>;
    /**
     * Register a handler for 'general-message-forward' events
     *
     * @param msg - The message sent by client
     */
    handleChatMessage(msg: unknown): void;
    /**
     * Register a handler for 'general-message' events
     *
     * @param msg - The message sent by client
     */
    handleGeneralMessage(msg: string): void;
    /**
     * Register a handler for all events
     */
    logMessage(...args: unknown[]): void;
    /**
     * The method is invoked when a client disconnects from the server
     * @param socket
     */
    disconnect(): void;
}
